You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by cm...@apache.org on 2010/11/04 19:05:42 UTC

svn commit: r1031114 - /subversion/trunk/subversion/include/svn_client.h

Author: cmpilato
Date: Thu Nov  4 18:05:41 2010
New Revision: 1031114

URL: http://svn.apache.org/viewvc?rev=1031114&view=rev
Log:
Avoid 'swig-py' build warnings of this variety:

    'from' is a python keyword, renaming to '_from'

* subversion/include/svn_client.h
  (svn_client_relocate2, svn_client_relocate): Respectfully rename
    'from' and 'to' from 'from' and 'to' to 'from_prefix' and
    'to_prefix', respectively.
  (svn_client_export5, svn_client_export4, svn_client_export3,
   svn_client_export2, svn_client_export): Rename 'from' and 'to' to
    'from_path_or_url' and 'to_path', respectively.

Modified:
    subversion/trunk/subversion/include/svn_client.h

Modified: subversion/trunk/subversion/include/svn_client.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=1031114&r1=1031113&r2=1031114&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_client.h (original)
+++ subversion/trunk/subversion/include/svn_client.h Thu Nov  4 18:05:41 2010
@@ -3470,12 +3470,13 @@ svn_client_upgrade(const char *dir,
  */
 
 /**
  * Recursively modify a working copy rooted at @a wcroot_dir, changing any
  * repository URLs that begin with @a from to begin with @a to instead.
  *
  * @param wcroot_dir Working copy root directory
  * @param from Original URL
  * @param to New URL
  * @param ignore_externals If not set, recurse into external working
  *        copies after relocating the primary working copy
  * @param ctx svn_client_ctx_t
@@ -3485,8 +3486,8 @@ svn_client_upgrade(const char *dir,
  */
 svn_error_t *
 svn_client_relocate2(const char *wcroot_dir,
-                     const char *from,
-                     const char *to,
+                     const char *from_prefix,
+                     const char *to_prefix,
                      svn_boolean_t ignore_externals,
                      svn_client_ctx_t *ctx,
                      apr_pool_t *pool);
@@ -3504,8 +3505,8 @@ svn_client_relocate2(const char *wcroot_
 SVN_DEPRECATED
 svn_error_t *
 svn_client_relocate(const char *dir,
-                    const char *from,
-                    const char *to,
+                    const char *from_prefix,
+                    const char *to_prefix,
                     svn_boolean_t recurse,
                     svn_client_ctx_t *ctx,
                     apr_pool_t *pool);
@@ -4458,13 +4459,14 @@ svn_client_revprop_list(apr_hash_t **pro
  * @a *result_rev to the value of the revision actually exported (set
  * it to #SVN_INVALID_REVNUM for local exports).
  *
  * @a from is either the path the working copy on disk, or a URL to the
  * repository you wish to export.
  *
  * When exporting a directory @a to is the path to the directory where
  * you wish to create the exported tree, when exporting a file it is
  * the path of the file that will be created.  If @a to is the empty
  * path the name of the file/directory in the repository will be used.
  *
  * @a peg_revision is the revision where the path is first looked up
  * when exporting from a repository.  If @a peg_revision->kind is
@@ -4482,7 +4484,8 @@ svn_client_revprop_list(apr_hash_t **pro
  *
  * @a ctx is a context used for authentication in the repository case.
  *
- * @a overwrite if TRUE will cause the export to overwrite files or directories.
+ * @a overwrite if TRUE will cause the export to overwrite files or
+ * directories.
  *
  * If @a ignore_externals is set, don't process externals definitions
  * as part of this operation.
@@ -4490,17 +4493,18 @@ svn_client_revprop_list(apr_hash_t **pro
  * If @a ignore_keywords is set, don't expand keywords as part of this
  * operation.
  *
  * @a native_eol allows you to override the standard eol marker on the platform
  * you are running on.  Can be either "LF", "CR" or "CRLF" or NULL.  If NULL
  * will use the standard eol marker.  Any other value will cause the
  * #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
  *
  * If @a depth is #svn_depth_infinity, export fully recursively.
  * Else if it is #svn_depth_immediates, export @a from and its immediate
  * children (if any), but with subdirectories empty and at
  * #svn_depth_empty.  Else if #svn_depth_files, export @a from and
  * its immediate file children (if any) only.  If @a depth is
  * #svn_depth_empty, then export exactly @a from and none of its children.
  *
  * All allocations are done in @a pool.
  *
@@ -4508,8 +4512,8 @@ svn_client_revprop_list(apr_hash_t **pro
  */
 svn_error_t *
 svn_client_export5(svn_revnum_t *result_rev,
-                   const char *from,
-                   const char *to,
+                   const char *from_path_or_url,
+                   const char *to_path,
                    const svn_opt_revision_t *peg_revision,
                    const svn_opt_revision_t *revision,
                    svn_boolean_t overwrite,
@@ -4530,8 +4534,8 @@ svn_client_export5(svn_revnum_t *result_
  */
 svn_error_t *
 svn_client_export4(svn_revnum_t *result_rev,
-                   const char *from,
-                   const char *to,
+                   const char *from_path_or_url,
+                   const char *to_path,
                    const svn_opt_revision_t *peg_revision,
                    const svn_opt_revision_t *revision,
                    svn_boolean_t overwrite,
@@ -4555,8 +4559,8 @@ svn_client_export4(svn_revnum_t *result_
 SVN_DEPRECATED
 svn_error_t *
 svn_client_export3(svn_revnum_t *result_rev,
-                   const char *from,
-                   const char *to,
+                   const char *from_path_or_url,
+                   const char *to_path,
                    const svn_opt_revision_t *peg_revision,
                    const svn_opt_revision_t *revision,
                    svn_boolean_t overwrite,
@@ -4579,8 +4583,8 @@ svn_client_export3(svn_revnum_t *result_
 SVN_DEPRECATED
 svn_error_t *
 svn_client_export2(svn_revnum_t *result_rev,
-                   const char *from,
-                   const char *to,
+                   const char *from_path_or_url,
+                   const char *to_path,
                    svn_opt_revision_t *revision,
                    svn_boolean_t force,
                    const char *native_eol,
@@ -4597,8 +4601,8 @@ svn_client_export2(svn_revnum_t *result_
 SVN_DEPRECATED
 svn_error_t *
 svn_client_export(svn_revnum_t *result_rev,
-                  const char *from,
-                  const char *to,
+                  const char *from_path_or_url,
+                  const char *to_path,
                   svn_opt_revision_t *revision,
                   svn_boolean_t force,
                   svn_client_ctx_t *ctx,
@@ -3470,12 +3470,13 @@ svn_client_upgrade(const char *dir,
 
 /**
- * Recursively modify a working copy rooted at @a wcroot_dir, changing any
- * repository URLs that begin with @a from to begin with @a to instead.
+ * Recursively modify a working copy rooted at @a wcroot_dir, changing
+ * any repository URLs that begin with @a from_prefix to begin with @a
+ * to_prefix instead.
  *
  * @param wcroot_dir Working copy root directory
@@ -3470,12 +3470,13 @@ svn_client_upgrade(const char *dir,
  *
  * @param wcroot_dir Working copy root directory
- * @param from Original URL
- * @param to New URL
+ * @param from_prefix Original URL
+ * @param to_prefix New URL
  * @param ignore_externals If not set, recurse into external working
  *        copies after relocating the primary working copy
@@ -4458,13 +4459,14 @@ svn_client_revprop_list(apr_hash_t **pro
  * it to #SVN_INVALID_REVNUM for local exports).
  *
- * @a from is either the path the working copy on disk, or a URL to the
- * repository you wish to export.
+ * @a from_path_or_url is either the path the working copy on disk, or
+ * a URL to the repository you wish to export.
  *
@@ -4458,13 +4459,14 @@ svn_client_revprop_list(apr_hash_t **pro
  *
- * When exporting a directory @a to is the path to the directory where
- * you wish to create the exported tree, when exporting a file it is
- * the path of the file that will be created.  If @a to is the empty
- * path the name of the file/directory in the repository will be used.
+ * When exporting a directory @a to_path is the path to the directory
+ * where you wish to create the exported tree, when exporting a file
+ * it is the path of the file that will be created.  If @a to_path is
+ * the empty path the name of the file/directory in the repository
+ * will be used.
  *
  * @a peg_revision is the revision where the path is first looked up
@@ -4490,17 +4493,18 @@ svn_client_revprop_list(apr_hash_t **pro
  * operation.
  *
- * @a native_eol allows you to override the standard eol marker on the platform
- * you are running on.  Can be either "LF", "CR" or "CRLF" or NULL.  If NULL
- * will use the standard eol marker.  Any other value will cause the
- * #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
- *
- * If @a depth is #svn_depth_infinity, export fully recursively.
- * Else if it is #svn_depth_immediates, export @a from and its immediate
- * children (if any), but with subdirectories empty and at
- * #svn_depth_empty.  Else if #svn_depth_files, export @a from and
- * its immediate file children (if any) only.  If @a depth is
- * #svn_depth_empty, then export exactly @a from and none of its children.
+ * @a native_eol allows you to override the standard eol marker on the
+ * platform you are running on.  Can be either "LF", "CR" or "CRLF" or
+ * NULL.  If NULL will use the standard eol marker.  Any other value
+ * will cause the #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
+ *
+ * If @a depth is #svn_depth_infinity, export fully recursively.  Else
+ * if it is #svn_depth_immediates, export @a from_path_or_url and its
+ * immediate children (if any), but with subdirectories empty and at
+ * #svn_depth_empty.  Else if #svn_depth_files, export @a
+ * from_path_or_url and its immediate file children (if any) only.  If
+ * @a depth is #svn_depth_empty, then export exactly @a
+ * from_path_or_url and none of its children.
  *
  * All allocations are done in @a pool.



Re: svn commit: r1031114 - /subversion/trunk/subversion/include/svn_client.h

Posted by "C. Michael Pilato" <cm...@collab.net>.
On 11/04/2010 02:11 PM, Hyrum K. Wright wrote:
> On Thu, Nov 4, 2010 at 1:05 PM,  <cm...@apache.org> wrote:
>> Author: cmpilato
>> Date: Thu Nov  4 18:05:41 2010
>> New Revision: 1031114
>>
>> URL: http://svn.apache.org/viewvc?rev=1031114&view=rev
>> Log:
>> Avoid 'swig-py' build warnings of this variety:
>>
>>    'from' is a python keyword, renaming to '_from'
>>
>> * subversion/include/svn_client.h
>>  (svn_client_relocate2, svn_client_relocate): Respectfully rename
>>    'from' and 'to' from 'from' and 'to' to 'from_prefix' and
>>    'to_prefix', respectively.
>>  (svn_client_export5, svn_client_export4, svn_client_export3,
>>   svn_client_export2, svn_client_export): Rename 'from' and 'to' to
>>    'from_path_or_url' and 'to_path', respectively.
> 
> In the interests of consistency, should this change also be made in
> the actual function definitions?

Done.

-- 
C. Michael Pilato <cm...@collab.net>
CollabNet   <>   www.collab.net   <>   Distributed Development On Demand


Re: svn commit: r1031114 - /subversion/trunk/subversion/include/svn_client.h

Posted by "C. Michael Pilato" <cm...@collab.net>.
On 11/04/2010 02:11 PM, Hyrum K. Wright wrote:
> On Thu, Nov 4, 2010 at 1:05 PM,  <cm...@apache.org> wrote:
>> Author: cmpilato
>> Date: Thu Nov  4 18:05:41 2010
>> New Revision: 1031114
>>
>> URL: http://svn.apache.org/viewvc?rev=1031114&view=rev
>> Log:
>> Avoid 'swig-py' build warnings of this variety:
>>
>>    'from' is a python keyword, renaming to '_from'
>>
>> * subversion/include/svn_client.h
>>  (svn_client_relocate2, svn_client_relocate): Respectfully rename
>>    'from' and 'to' from 'from' and 'to' to 'from_prefix' and
>>    'to_prefix', respectively.
>>  (svn_client_export5, svn_client_export4, svn_client_export3,
>>   svn_client_export2, svn_client_export): Rename 'from' and 'to' to
>>    'from_path_or_url' and 'to_path', respectively.
> 
> In the interests of consistency, should this change also be made in
> the actual function definitions?

Done.

-- 
C. Michael Pilato <cm...@collab.net>
CollabNet   <>   www.collab.net   <>   Distributed Development On Demand


Re: svn commit: r1031114 - /subversion/trunk/subversion/include/svn_client.h

Posted by "Hyrum K. Wright" <hy...@mail.utexas.edu>.
On Thu, Nov 4, 2010 at 1:05 PM,  <cm...@apache.org> wrote:
> Author: cmpilato
> Date: Thu Nov  4 18:05:41 2010
> New Revision: 1031114
>
> URL: http://svn.apache.org/viewvc?rev=1031114&view=rev
> Log:
> Avoid 'swig-py' build warnings of this variety:
>
>    'from' is a python keyword, renaming to '_from'
>
> * subversion/include/svn_client.h
>  (svn_client_relocate2, svn_client_relocate): Respectfully rename
>    'from' and 'to' from 'from' and 'to' to 'from_prefix' and
>    'to_prefix', respectively.
>  (svn_client_export5, svn_client_export4, svn_client_export3,
>   svn_client_export2, svn_client_export): Rename 'from' and 'to' to
>    'from_path_or_url' and 'to_path', respectively.

In the interests of consistency, should this change also be made in
the actual function definitions?

>
> Modified:
>    subversion/trunk/subversion/include/svn_client.h
>
> Modified: subversion/trunk/subversion/include/svn_client.h
> URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=1031114&r1=1031113&r2=1031114&view=diff
> ==============================================================================
> --- subversion/trunk/subversion/include/svn_client.h (original)
> +++ subversion/trunk/subversion/include/svn_client.h Thu Nov  4 18:05:41 2010
> @@ -3470,12 +3470,13 @@ svn_client_upgrade(const char *dir,
>  */
>
>  /**
> - * Recursively modify a working copy rooted at @a wcroot_dir, changing any
> - * repository URLs that begin with @a from to begin with @a to instead.
> + * Recursively modify a working copy rooted at @a wcroot_dir, changing
> + * any repository URLs that begin with @a from_prefix to begin with @a
> + * to_prefix instead.
>  *
>  * @param wcroot_dir Working copy root directory
> - * @param from Original URL
> - * @param to New URL
> + * @param from_prefix Original URL
> + * @param to_prefix New URL
>  * @param ignore_externals If not set, recurse into external working
>  *        copies after relocating the primary working copy
>  * @param ctx svn_client_ctx_t
> @@ -3485,8 +3486,8 @@ svn_client_upgrade(const char *dir,
>  */
>  svn_error_t *
>  svn_client_relocate2(const char *wcroot_dir,
> -                     const char *from,
> -                     const char *to,
> +                     const char *from_prefix,
> +                     const char *to_prefix,
>                      svn_boolean_t ignore_externals,
>                      svn_client_ctx_t *ctx,
>                      apr_pool_t *pool);
> @@ -3504,8 +3505,8 @@ svn_client_relocate2(const char *wcroot_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_relocate(const char *dir,
> -                    const char *from,
> -                    const char *to,
> +                    const char *from_prefix,
> +                    const char *to_prefix,
>                     svn_boolean_t recurse,
>                     svn_client_ctx_t *ctx,
>                     apr_pool_t *pool);
> @@ -4458,13 +4459,14 @@ svn_client_revprop_list(apr_hash_t **pro
>  * @a *result_rev to the value of the revision actually exported (set
>  * it to #SVN_INVALID_REVNUM for local exports).
>  *
> - * @a from is either the path the working copy on disk, or a URL to the
> - * repository you wish to export.
> + * @a from_path_or_url is either the path the working copy on disk, or
> + * a URL to the repository you wish to export.
>  *
> - * When exporting a directory @a to is the path to the directory where
> - * you wish to create the exported tree, when exporting a file it is
> - * the path of the file that will be created.  If @a to is the empty
> - * path the name of the file/directory in the repository will be used.
> + * When exporting a directory @a to_path is the path to the directory
> + * where you wish to create the exported tree, when exporting a file
> + * it is the path of the file that will be created.  If @a to_path is
> + * the empty path the name of the file/directory in the repository
> + * will be used.
>  *
>  * @a peg_revision is the revision where the path is first looked up
>  * when exporting from a repository.  If @a peg_revision->kind is
> @@ -4482,7 +4484,8 @@ svn_client_revprop_list(apr_hash_t **pro
>  *
>  * @a ctx is a context used for authentication in the repository case.
>  *
> - * @a overwrite if TRUE will cause the export to overwrite files or directories.
> + * @a overwrite if TRUE will cause the export to overwrite files or
> + * directories.
>  *
>  * If @a ignore_externals is set, don't process externals definitions
>  * as part of this operation.
> @@ -4490,17 +4493,18 @@ svn_client_revprop_list(apr_hash_t **pro
>  * If @a ignore_keywords is set, don't expand keywords as part of this
>  * operation.
>  *
> - * @a native_eol allows you to override the standard eol marker on the platform
> - * you are running on.  Can be either "LF", "CR" or "CRLF" or NULL.  If NULL
> - * will use the standard eol marker.  Any other value will cause the
> - * #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
> - *
> - * If @a depth is #svn_depth_infinity, export fully recursively.
> - * Else if it is #svn_depth_immediates, export @a from and its immediate
> - * children (if any), but with subdirectories empty and at
> - * #svn_depth_empty.  Else if #svn_depth_files, export @a from and
> - * its immediate file children (if any) only.  If @a depth is
> - * #svn_depth_empty, then export exactly @a from and none of its children.
> + * @a native_eol allows you to override the standard eol marker on the
> + * platform you are running on.  Can be either "LF", "CR" or "CRLF" or
> + * NULL.  If NULL will use the standard eol marker.  Any other value
> + * will cause the #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
> + *
> + * If @a depth is #svn_depth_infinity, export fully recursively.  Else
> + * if it is #svn_depth_immediates, export @a from_path_or_url and its
> + * immediate children (if any), but with subdirectories empty and at
> + * #svn_depth_empty.  Else if #svn_depth_files, export @a
> + * from_path_or_url and its immediate file children (if any) only.  If
> + * @a depth is #svn_depth_empty, then export exactly @a
> + * from_path_or_url and none of its children.
>  *
>  * All allocations are done in @a pool.
>  *
> @@ -4508,8 +4512,8 @@ svn_client_revprop_list(apr_hash_t **pro
>  */
>  svn_error_t *
>  svn_client_export5(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4530,8 +4534,8 @@ svn_client_export5(svn_revnum_t *result_
>  */
>  svn_error_t *
>  svn_client_export4(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4555,8 +4559,8 @@ svn_client_export4(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export3(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4579,8 +4583,8 @@ svn_client_export3(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export2(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    svn_opt_revision_t *revision,
>                    svn_boolean_t force,
>                    const char *native_eol,
> @@ -4597,8 +4601,8 @@ svn_client_export2(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export(svn_revnum_t *result_rev,
> -                  const char *from,
> -                  const char *to,
> +                  const char *from_path_or_url,
> +                  const char *to_path,
>                   svn_opt_revision_t *revision,
>                   svn_boolean_t force,
>                   svn_client_ctx_t *ctx,
>
>
>

Re: svn commit: r1031114 - /subversion/trunk/subversion/include/svn_client.h

Posted by "Hyrum K. Wright" <hy...@mail.utexas.edu>.
On Thu, Nov 4, 2010 at 1:05 PM,  <cm...@apache.org> wrote:
> Author: cmpilato
> Date: Thu Nov  4 18:05:41 2010
> New Revision: 1031114
>
> URL: http://svn.apache.org/viewvc?rev=1031114&view=rev
> Log:
> Avoid 'swig-py' build warnings of this variety:
>
>    'from' is a python keyword, renaming to '_from'
>
> * subversion/include/svn_client.h
>  (svn_client_relocate2, svn_client_relocate): Respectfully rename
>    'from' and 'to' from 'from' and 'to' to 'from_prefix' and
>    'to_prefix', respectively.
>  (svn_client_export5, svn_client_export4, svn_client_export3,
>   svn_client_export2, svn_client_export): Rename 'from' and 'to' to
>    'from_path_or_url' and 'to_path', respectively.

In the interests of consistency, should this change also be made in
the actual function definitions?

>
> Modified:
>    subversion/trunk/subversion/include/svn_client.h
>
> Modified: subversion/trunk/subversion/include/svn_client.h
> URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=1031114&r1=1031113&r2=1031114&view=diff
> ==============================================================================
> --- subversion/trunk/subversion/include/svn_client.h (original)
> +++ subversion/trunk/subversion/include/svn_client.h Thu Nov  4 18:05:41 2010
> @@ -3470,12 +3470,13 @@ svn_client_upgrade(const char *dir,
>  */
>
>  /**
> - * Recursively modify a working copy rooted at @a wcroot_dir, changing any
> - * repository URLs that begin with @a from to begin with @a to instead.
> + * Recursively modify a working copy rooted at @a wcroot_dir, changing
> + * any repository URLs that begin with @a from_prefix to begin with @a
> + * to_prefix instead.
>  *
>  * @param wcroot_dir Working copy root directory
> - * @param from Original URL
> - * @param to New URL
> + * @param from_prefix Original URL
> + * @param to_prefix New URL
>  * @param ignore_externals If not set, recurse into external working
>  *        copies after relocating the primary working copy
>  * @param ctx svn_client_ctx_t
> @@ -3485,8 +3486,8 @@ svn_client_upgrade(const char *dir,
>  */
>  svn_error_t *
>  svn_client_relocate2(const char *wcroot_dir,
> -                     const char *from,
> -                     const char *to,
> +                     const char *from_prefix,
> +                     const char *to_prefix,
>                      svn_boolean_t ignore_externals,
>                      svn_client_ctx_t *ctx,
>                      apr_pool_t *pool);
> @@ -3504,8 +3505,8 @@ svn_client_relocate2(const char *wcroot_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_relocate(const char *dir,
> -                    const char *from,
> -                    const char *to,
> +                    const char *from_prefix,
> +                    const char *to_prefix,
>                     svn_boolean_t recurse,
>                     svn_client_ctx_t *ctx,
>                     apr_pool_t *pool);
> @@ -4458,13 +4459,14 @@ svn_client_revprop_list(apr_hash_t **pro
>  * @a *result_rev to the value of the revision actually exported (set
>  * it to #SVN_INVALID_REVNUM for local exports).
>  *
> - * @a from is either the path the working copy on disk, or a URL to the
> - * repository you wish to export.
> + * @a from_path_or_url is either the path the working copy on disk, or
> + * a URL to the repository you wish to export.
>  *
> - * When exporting a directory @a to is the path to the directory where
> - * you wish to create the exported tree, when exporting a file it is
> - * the path of the file that will be created.  If @a to is the empty
> - * path the name of the file/directory in the repository will be used.
> + * When exporting a directory @a to_path is the path to the directory
> + * where you wish to create the exported tree, when exporting a file
> + * it is the path of the file that will be created.  If @a to_path is
> + * the empty path the name of the file/directory in the repository
> + * will be used.
>  *
>  * @a peg_revision is the revision where the path is first looked up
>  * when exporting from a repository.  If @a peg_revision->kind is
> @@ -4482,7 +4484,8 @@ svn_client_revprop_list(apr_hash_t **pro
>  *
>  * @a ctx is a context used for authentication in the repository case.
>  *
> - * @a overwrite if TRUE will cause the export to overwrite files or directories.
> + * @a overwrite if TRUE will cause the export to overwrite files or
> + * directories.
>  *
>  * If @a ignore_externals is set, don't process externals definitions
>  * as part of this operation.
> @@ -4490,17 +4493,18 @@ svn_client_revprop_list(apr_hash_t **pro
>  * If @a ignore_keywords is set, don't expand keywords as part of this
>  * operation.
>  *
> - * @a native_eol allows you to override the standard eol marker on the platform
> - * you are running on.  Can be either "LF", "CR" or "CRLF" or NULL.  If NULL
> - * will use the standard eol marker.  Any other value will cause the
> - * #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
> - *
> - * If @a depth is #svn_depth_infinity, export fully recursively.
> - * Else if it is #svn_depth_immediates, export @a from and its immediate
> - * children (if any), but with subdirectories empty and at
> - * #svn_depth_empty.  Else if #svn_depth_files, export @a from and
> - * its immediate file children (if any) only.  If @a depth is
> - * #svn_depth_empty, then export exactly @a from and none of its children.
> + * @a native_eol allows you to override the standard eol marker on the
> + * platform you are running on.  Can be either "LF", "CR" or "CRLF" or
> + * NULL.  If NULL will use the standard eol marker.  Any other value
> + * will cause the #SVN_ERR_IO_UNKNOWN_EOL error to be returned.
> + *
> + * If @a depth is #svn_depth_infinity, export fully recursively.  Else
> + * if it is #svn_depth_immediates, export @a from_path_or_url and its
> + * immediate children (if any), but with subdirectories empty and at
> + * #svn_depth_empty.  Else if #svn_depth_files, export @a
> + * from_path_or_url and its immediate file children (if any) only.  If
> + * @a depth is #svn_depth_empty, then export exactly @a
> + * from_path_or_url and none of its children.
>  *
>  * All allocations are done in @a pool.
>  *
> @@ -4508,8 +4512,8 @@ svn_client_revprop_list(apr_hash_t **pro
>  */
>  svn_error_t *
>  svn_client_export5(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4530,8 +4534,8 @@ svn_client_export5(svn_revnum_t *result_
>  */
>  svn_error_t *
>  svn_client_export4(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4555,8 +4559,8 @@ svn_client_export4(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export3(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    const svn_opt_revision_t *peg_revision,
>                    const svn_opt_revision_t *revision,
>                    svn_boolean_t overwrite,
> @@ -4579,8 +4583,8 @@ svn_client_export3(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export2(svn_revnum_t *result_rev,
> -                   const char *from,
> -                   const char *to,
> +                   const char *from_path_or_url,
> +                   const char *to_path,
>                    svn_opt_revision_t *revision,
>                    svn_boolean_t force,
>                    const char *native_eol,
> @@ -4597,8 +4601,8 @@ svn_client_export2(svn_revnum_t *result_
>  SVN_DEPRECATED
>  svn_error_t *
>  svn_client_export(svn_revnum_t *result_rev,
> -                  const char *from,
> -                  const char *to,
> +                  const char *from_path_or_url,
> +                  const char *to_path,
>                   svn_opt_revision_t *revision,
>                   svn_boolean_t force,
>                   svn_client_ctx_t *ctx,
>
>
>